==> milton-server-ce-3.0.0.232-sources.jar: io/milton/servlet/MiltonUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milton.servlet;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.ServletContext;

public class MiltonUtils {
    public static String stripContext(HttpServletRequest req) {
        String s = req.getRequestURI();        
        String contextPath = req.getContextPath();        
        s = s.replaceFirst( contextPath  , "" );
        return s;
    }
    
    /**
     * 
     * @param context - context to look up mime associations with
     * @param fileName - name of a file to look for mime associations of
     * 
     * @return - a single content type spec
     */
    public static String getContentType(ServletContext context, String fileName) {
        return context.getMimeType(fileName);
    }
}

==> milton-server-ce-4.0.4.2305-sources.jar: io/milton/servlet/MiltonUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milton.servlet;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.ServletContext;

public class MiltonUtils {
    public static String stripContext(HttpServletRequest req) {
        String s = req.getRequestURI();        
        String contextPath = req.getContextPath();        
        s = s.replaceFirst( contextPath  , "" );
        return s;
    }
    
    /**
     * 
     * @param context - context to look up mime associations with
     * @param fileName - name of a file to look for mime associations of
     * 
     * @return - a single content type spec
     */
    public static String getContentType(ServletContext context, String fileName) {
        return context.getMimeType(fileName);
    }
}
